"""Constants that define tiers"""

FREE = 'free'
STARTUP = 'startup'
STANDARD = 'standard'
FLEXI = 'flexi'
